Grids
=====

.. currentmodule:: fastscapelib

Grid elements
-------------

.. autosummary::
   :toctree: _api_generated/

   NodeStatus
   Node
   RasterNode
   Neighbor
   RasterNeighbor

Grid boundaries
---------------

.. autosummary::
   :toctree: _api_generated/
   :template: fastscapelib-class-template.rst

   ProfileBoundaryStatus
   RasterBoundaryStatus

Grids
-----

.. autosummary::
   :toctree: _api_generated/
   :template: fastscapelib-class-template.rst

   ProfileGrid
   RasterGrid
   TriMesh
